@@ -7,7 +7,7 @@ use parent qw( Alien::Base );
 use Path::Tiny;
 use File::ShareDir::Dist qw( dist_share );
 
-our $VERSION = '1.001000';
+our $VERSION = '1.001001';
 
 sub bin_dir { path( dist_share __PACKAGE__ )->child('bin') }
 
@@ -43,7 +43,7 @@ Alien::ultraviolet - Alien package for Python uv
 
 L<Alien::ultraviolet> downloads and installs uv.
 
-However, setting C<ALIEN_INSTALL_TYPE=system> will force use of system uv.
+However, setting C<ALIEN_ULTRAVIOLET_INSTALL_TYPE=system> will force use of system uv.
 
 =head1 METHODS
 
